@@ -14,7 +14,8 @@ from .plugin_downloader import PluginDownloader
 
 print("""
 Use one of the following commands to start using PyAlink:
- - useLocalEnv(parallelism, flinkHome=None, config=None)
- - useRemoteEnv(host, port, parallelism, flinkHome=None, localIp="localhost", config=None)
+ - useLocalEnv(parallelism, flinkHome=None, config=None): run PyAlink scripts locally.
+ - useRemoteEnv(host, port, parallelism, flinkHome=None, localIp="localhost", config=None): run PyAlink scripts on a Flink cluster.
+ - getMLEnv(): run PyAlink scripts as PyFlink scripts, support 'flink run -py xxx.py'.
 Call resetEnv() to reset environment and switch to another.
 """)
