@@ -31,6 +31,15 @@ class AftSurvivalRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -85,6 +94,38 @@ class AftSurvivalRegTrainBatchOp(BatchOperator, WithModelInfoBatchOp, WithTrainI
         return self._add_param('withIntercept', val)
 
 
+class AggLookupBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.AggLookupBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AggLookupBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+    def setDelimiter(self, val):
+        return self._add_param('delimiter', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class AkSinkBatchOp(BaseSinkBatchOp):
     CLS_NAME = 'com.alibaba.alink.operator.batch.sink.AkSinkBatchOp'
     OP_TYPE = 'SINK'
@@ -176,9 +217,21 @@ class AlsItemsPerUserRecommBatchOp(BatchOperator):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -216,6 +269,15 @@ class AlsRateRecommBatchOp(BatchOperator):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -239,9 +301,21 @@ class AlsSimilarItemsRecommBatchOp(BatchOperator):
     def setRecommCol(self, val):
         return self._add_param('recommCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -265,9 +339,21 @@ class AlsSimilarUsersRecommBatchOp(BatchOperator):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -329,9 +415,21 @@ class AlsUsersPerItemRecommBatchOp(BatchOperator):
     def setExcludeKnown(self, val):
         return self._add_param('excludeKnown', val)
 
+    def setInitRecommCol(self, val):
+        return self._add_param('initRecommCol', val)
+
     def setK(self, val):
         return self._add_param('k', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -356,6 +454,70 @@ class AppendIdBatchOp(BatchOperator):
         return self._add_param('idCol', val)
 
 
+class AppendModelStreamFileSinkBatchOp(BaseSinkBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.sink.AppendModelStreamFileSinkBatchOp'
+    OP_TYPE = 'SINK'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AppendModelStreamFileSinkBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFilePath(self, val):
+        return self._add_param('filePath', val)
+
+    def setModelTime(self, val):
+        return self._add_param('modelTime', val)
+
+    def setNumFiles(self, val):
+        return self._add_param('numFiles', val)
+
+    def setNumKeepModel(self, val):
+        return self._add_param('numKeepModel', val)
+
+
+class ArimaBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.ArimaBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ArimaBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOrder(self, val):
+        return self._add_param('order', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setEstMethod(self, val):
+        return self._add_param('estMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeasonalOrder(self, val):
+        return self._add_param('seasonalOrder', val)
+
+    def setSeasonalPeriod(self, val):
+        return self._add_param('seasonalPeriod', val)
+
+
 class AsBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.sql.AsBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -370,6 +532,502 @@ class AsBatchOp(BatchOperator):
         return self._add_param('clause', val)
 
 
+class AutoArimaBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.AutoArimaBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AutoArimaBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setD(self, val):
+        return self._add_param('d', val)
+
+    def setEstMethod(self, val):
+        return self._add_param('estMethod', val)
+
+    def setIcType(self, val):
+        return self._add_param('icType', val)
+
+    def setMaxOrder(self, val):
+        return self._add_param('maxOrder', val)
+
+    def setMaxSeasonalOrder(self, val):
+        return self._add_param('maxSeasonalOrder', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeasonalPeriod(self, val):
+        return self._add_param('seasonalPeriod', val)
+
+
+class AutoGarchBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.timeseries.AutoGarchBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AutoGarchBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setIcType(self, val):
+        return self._add_param('icType', val)
+
+    def setIfGARCH11(self, val):
+        return self._add_param('ifGARCH11', val)
+
+    def setMaxOrder(self, val):
+        return self._add_param('maxOrder', val)
+
+    def setMinusMean(self, val):
+        return self._add_param('minusMean', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextClassifierPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.BertTextClassifierPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextClassifierPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextClassifierTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.BertTextClassifierTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextClassifierTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setTaskName(self, val):
+        return self._add_param('taskName', val)
+
+    def setTaskType(self, val):
+        return self._add_param('taskType', val)
+
+    def setTextCol(self, val):
+        return self._add_param('textCol', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setBertModelName(self, val):
+        return self._add_param('bertModelName', val)
+
+    def setCheckpointFilePath(self, val):
+        return self._add_param('checkpointFilePath', val)
+
+    def setCustomConfigJson(self, val):
+        return self._add_param('customConfigJson', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setLearningRate(self, val):
+        return self._add_param('learningRate', val)
+
+    def setMaxSeqLength(self, val):
+        return self._add_param('maxSeqLength', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFineTunedLayers(self, val):
+        return self._add_param('numFineTunedLayers', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setRemoveCheckpointBeforeTraining(self, val):
+        return self._add_param('removeCheckpointBeforeTraining', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setTextPairCol(self, val):
+        return self._add_param('textPairCol', val)
+
+
+class BertTextEmbeddingBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.nlp.BertTextEmbeddingBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextEmbeddingBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setBertModelName(self, val):
+        return self._add_param('bertModelName', val)
+
+    def setDoLowerCase(self, val):
+        return self._add_param('doLowerCase', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setLayer(self, val):
+        return self._add_param('layer', val)
+
+    def setMaxSeqLength(self, val):
+        return self._add_param('maxSeqLength', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextPairClassifierPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.BertTextPairClassifierPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextPairClassifierPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextPairClassifierTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.BertTextPairClassifierTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextPairClassifierTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setTaskName(self, val):
+        return self._add_param('taskName', val)
+
+    def setTaskType(self, val):
+        return self._add_param('taskType', val)
+
+    def setTextCol(self, val):
+        return self._add_param('textCol', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setBertModelName(self, val):
+        return self._add_param('bertModelName', val)
+
+    def setCheckpointFilePath(self, val):
+        return self._add_param('checkpointFilePath', val)
+
+    def setCustomConfigJson(self, val):
+        return self._add_param('customConfigJson', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setLearningRate(self, val):
+        return self._add_param('learningRate', val)
+
+    def setMaxSeqLength(self, val):
+        return self._add_param('maxSeqLength', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFineTunedLayers(self, val):
+        return self._add_param('numFineTunedLayers', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setRemoveCheckpointBeforeTraining(self, val):
+        return self._add_param('removeCheckpointBeforeTraining', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setTextPairCol(self, val):
+        return self._add_param('textPairCol', val)
+
+
+class BertTextPairRegressorPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.BertTextPairRegressorPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextPairRegressorPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextPairRegressorTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.BertTextPairRegressorTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextPairRegressorTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setTaskName(self, val):
+        return self._add_param('taskName', val)
+
+    def setTaskType(self, val):
+        return self._add_param('taskType', val)
+
+    def setTextCol(self, val):
+        return self._add_param('textCol', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setBertModelName(self, val):
+        return self._add_param('bertModelName', val)
+
+    def setCheckpointFilePath(self, val):
+        return self._add_param('checkpointFilePath', val)
+
+    def setCustomConfigJson(self, val):
+        return self._add_param('customConfigJson', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setLearningRate(self, val):
+        return self._add_param('learningRate', val)
+
+    def setMaxSeqLength(self, val):
+        return self._add_param('maxSeqLength', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFineTunedLayers(self, val):
+        return self._add_param('numFineTunedLayers', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setRemoveCheckpointBeforeTraining(self, val):
+        return self._add_param('removeCheckpointBeforeTraining', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setTextPairCol(self, val):
+        return self._add_param('textPairCol', val)
+
+
+class BertTextRegressorPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.BertTextRegressorPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextRegressorPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextRegressorTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.regression.BertTextRegressorTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextRegressorTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setTaskName(self, val):
+        return self._add_param('taskName', val)
+
+    def setTaskType(self, val):
+        return self._add_param('taskType', val)
+
+    def setTextCol(self, val):
+        return self._add_param('textCol', val)
+
+    def setBatchSize(self, val):
+        return self._add_param('batchSize', val)
+
+    def setBertModelName(self, val):
+        return self._add_param('bertModelName', val)
+
+    def setCheckpointFilePath(self, val):
+        return self._add_param('checkpointFilePath', val)
+
+    def setCustomConfigJson(self, val):
+        return self._add_param('customConfigJson', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setLearningRate(self, val):
+        return self._add_param('learningRate', val)
+
+    def setMaxSeqLength(self, val):
+        return self._add_param('maxSeqLength', val)
+
+    def setNumEpochs(self, val):
+        return self._add_param('numEpochs', val)
+
+    def setNumFineTunedLayers(self, val):
+        return self._add_param('numFineTunedLayers', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setRemoveCheckpointBeforeTraining(self, val):
+        return self._add_param('removeCheckpointBeforeTraining', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setTextPairCol(self, val):
+        return self._add_param('textPairCol', val)
+
+
 class BinarizerBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.feature.BinarizerBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -383,6 +1041,9 @@ class BinarizerBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
@@ -417,6 +1078,15 @@ class BisectingKMeansPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -487,6 +1157,15 @@ class BucketizerBatchOp(BatchOperator):
     def setLeftOpen(self, val):
         return self._add_param('leftOpen', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -521,6 +1200,15 @@ class C45PredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -602,6 +1290,15 @@ class CartPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -636,6 +1333,15 @@ class CartRegPredictBatchOp(BatchOperator):
     def setPredictionCol(self, val):
         return self._add_param('predictionCol', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -882,385 +1588,3 @@ class ColumnsToJsonBatchOp(BatchOperator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
-
-class ColumnsToKvBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.ColumnsToKvBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(ColumnsToKvBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-
-class ColumnsToTripleBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.ColumnsToTripleBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(ColumnsToTripleBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setTripleColumnValueSchemaStr(self, val):
-        return self._add_param('tripleColumnValueSchemaStr', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-
-class ColumnsToVectorBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.ColumnsToVectorBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(ColumnsToVectorBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-
-class CorrelationBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.statistics.CorrelationBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CorrelationBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setMethod(self, val):
-        return self._add_param('method', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-
-class CsvSinkBatchOp(BaseSinkBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.sink.CsvSinkBatchOp'
-    OP_TYPE = 'SINK'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvSinkBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFilePath(self, val):
-        return self._add_param('filePath', val)
-
-    def setFieldDelimiter(self, val):
-        return self._add_param('fieldDelimiter', val)
-
-    def setNumFiles(self, val):
-        return self._add_param('numFiles', val)
-
-    def setOverwriteSink(self, val):
-        return self._add_param('overwriteSink', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setRowDelimiter(self, val):
-        return self._add_param('rowDelimiter', val)
-
-
-class CsvSourceBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.source.CsvSourceBatchOp'
-    OP_TYPE = 'SOURCE'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvSourceBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setFilePath(self, val):
-        return self._add_param('filePath', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setFieldDelimiter(self, val):
-        return self._add_param('fieldDelimiter', val)
-
-    def setIgnoreFirstLine(self, val):
-        return self._add_param('ignoreFirstLine', val)
-
-    def setLenient(self, val):
-        return self._add_param('lenient', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setRowDelimiter(self, val):
-        return self._add_param('rowDelimiter', val)
-
-    def setSkipBlankLine(self, val):
-        return self._add_param('skipBlankLine', val)
-
-
-class CsvToColumnsBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.CsvToColumnsBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvToColumnsBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class CsvToJsonBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.CsvToJsonBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvToJsonBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setJsonCol(self, val):
-        return self._add_param('jsonCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class CsvToKvBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.CsvToKvBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvToKvBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class CsvToTripleBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.CsvToTripleBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvToTripleBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setTripleColumnValueSchemaStr(self, val):
-        return self._add_param('tripleColumnValueSchemaStr', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class CsvToVectorBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.CsvToVectorBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(CsvToVectorBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-
-class DCTBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.feature.DCTBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(DCTBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setInverse(self, val):
-        return self._add_param('inverse', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class DecisionTreeModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.DecisionTreeModelInfoBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(DecisionTreeModelInfoBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-
-class DecisionTreePredictBatchOp(BatchOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.batch.classification.DecisionTreePredictBatchOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(DecisionTreePredictBatchOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
