@@ -8,6 +8,489 @@ from ..lazy.has_lazy_print_train_info import HasLazyPrintTrainInfo
 from ..local_predictor import LocalPredictable
 
 
+class RandomForestEncoderModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.RandomForestEncoderModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestEncoderModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class RandomForestRegEncoder(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.RandomForestRegEncoder'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestRegEncoder, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setCreateTreeMode(self, val):
+        return self._add_param('createTreeMode', val)
+
+    def setMaxBins(self, val):
+        return self._add_param('maxBins', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMaxMemoryInMB(self, val):
+        return self._add_param('maxMemoryInMB', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumSubsetFeatures(self, val):
+        return self._add_param('numSubsetFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
+class RandomForestRegEncoderModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.feature.RandomForestRegEncoderModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestRegEncoderModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class RandomForestRegressionModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.RandomForestRegressionModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestRegressionModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class RandomForestRegressor(Estimator, HasLazyPrintModelInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.RandomForestRegressor'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomForestRegressor, self).__init__(*args, **kwargs)
+        pass
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setCategoricalCols(self, val):
+        return self._add_param('categoricalCols', val)
+
+    def setCreateTreeMode(self, val):
+        return self._add_param('createTreeMode', val)
+
+    def setMaxBins(self, val):
+        return self._add_param('maxBins', val)
+
+    def setMaxDepth(self, val):
+        return self._add_param('maxDepth', val)
+
+    def setMaxLeaves(self, val):
+        return self._add_param('maxLeaves', val)
+
+    def setMaxMemoryInMB(self, val):
+        return self._add_param('maxMemoryInMB', val)
+
+    def setMinInfoGain(self, val):
+        return self._add_param('minInfoGain', val)
+
+    def setMinSampleRatioPerChild(self, val):
+        return self._add_param('minSampleRatioPerChild', val)
+
+    def setMinSamplesPerLeaf(self, val):
+        return self._add_param('minSamplesPerLeaf', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumSubsetFeatures(self, val):
+        return self._add_param('numSubsetFeatures', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setNumTrees(self, val):
+        return self._add_param('numTrees', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setSubsamplingRatio(self, val):
+        return self._add_param('subsamplingRatio', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+
+class RandomSearchCV(BaseRandomSearch, HasLazyPrintTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tuning.RandomSearchCV'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomSearchCV, self).__init__(*args, **kwargs)
+        pass
+
+    def setNumFolds(self, val):
+        return self._add_param('NumFolds', val)
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+
+class RandomSearchCVModel(Model):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tuning.RandomSearchCVModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomSearchCVModel, self).__init__(*args, **kwargs)
+        pass
+
+
+class RandomSearchTVSplit(BaseRandomSearch, HasLazyPrintTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tuning.RandomSearchTVSplit'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomSearchTVSplit, self).__init__(*args, **kwargs)
+        pass
+
+    def setNumIter(self, val):
+        return self._add_param('numIter', val)
+
+    def setTrainRatio(self, val):
+        return self._add_param('trainRatio', val)
+
+
+class RandomSearchTVSplitModel(Model):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tuning.RandomSearchTVSplitModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RandomSearchTVSplitModel, self).__init__(*args, **kwargs)
+        pass
+
+
+class RegexTokenizer(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.RegexTokenizer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RegexTokenizer, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setGaps(self, val):
+        return self._add_param('gaps', val)
+
+    def setMinTokenLength(self, val):
+        return self._add_param('minTokenLength', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setPattern(self, val):
+        return self._add_param('pattern', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setToLowerCase(self, val):
+        return self._add_param('toLowerCase', val)
+
+
+class RegressionTuningEvaluator(TuningEvaluator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tuning.RegressionTuningEvaluator'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RegressionTuningEvaluator, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setTuningRegressionMetric(self, val):
+        return self._add_param('tuningRegressionMetric', val)
+
+
+class RidgeRegression(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.RidgeRegression'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RidgeRegression, self).__init__(*args, **kwargs)
+        pass
+
+    def setLabelCol(self, val):
+        return self._add_param('labelCol', val)
+
+    def setLambda(self, val):
+        return self._add_param('lambda', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setEpsilon(self, val):
+        return self._add_param('epsilon', val)
+
+    def setFeatureCols(self, val):
+        return self._add_param('featureCols', val)
+
+    def setMaxIter(self, val):
+        return self._add_param('maxIter', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOptimMethod(self, val):
+        return self._add_param('optimMethod', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setStandardization(self, val):
+        return self._add_param('standardization', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+    def setWeightCol(self, val):
+        return self._add_param('weightCol', val)
+
+    def setWithIntercept(self, val):
+        return self._add_param('withIntercept', val)
+
+
+class RidgeRegressionModel(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.regression.RidgeRegressionModel'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(RidgeRegressionModel, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class Segment(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.Segment'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(Segment, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setUserDefinedDict(self, val):
+        return self._add_param('userDefinedDict', val)
+
+
+class Select(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.sql.Select'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(Select, self).__init__(*args, **kwargs)
+        pass
+
+    def setClause(self, val):
+        return self._add_param('clause', val)
+
+
 class Softmax(Estimator, HasLazyPrintModelInfo, HasLazyPrintTrainInfo):
     CLS_NAME = 'com.alibaba.alink.pipeline.classification.Softmax'
     OP_TYPE = 'FUNCTION'
@@ -417,6 +900,47 @@ class StringNearestNeighborModel(Model, LocalPredictable):
         return self._add_param('topN', val)
 
 
+class StringSimilarityPairwise(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.similarity.StringSimilarityPairwise'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StringSimilarityPairwise, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setLambda(self, val):
+        return self._add_param('lambda', val)
+
+    def setMetric(self, val):
+        return self._add_param('metric', val)
+
+    def setNumBucket(self, val):
+        return self._add_param('numBucket', val)
+
+    def setNumHashTables(self, val):
+        return self._add_param('numHashTables', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeed(self, val):
+        return self._add_param('seed', val)
+
+    def setWindowSize(self, val):
+        return self._add_param('windowSize', val)
+
+
 class SwingSimilarItemsRecommender(Model, LocalPredictable):
     CLS_NAME = 'com.alibaba.alink.pipeline.recommendation.SwingSimilarItemsRecommender'
     OP_TYPE = 'FUNCTION'
@@ -455,6 +979,152 @@ class SwingSimilarItemsRecommender(Model, LocalPredictable):
         return self._add_param('reservedCols', val)
 
 
+class TFSavedModelPredictor(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tensorflow.TFSavedModelPredictor'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TFSavedModelPredictor, self).__init__(*args, **kwargs)
+        pass
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setOutputSchemaStr(self, val):
+        return self._add_param('outputSchemaStr', val)
+
+    def setGraphDefTag(self, val):
+        return self._add_param('graphDefTag', val)
+
+    def setInputSignatureDefs(self, val):
+        return self._add_param('inputSignatureDefs', val)
+
+    def setOutputSignatureDefs(self, val):
+        return self._add_param('outputSignatureDefs', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setSignatureDefKey(self, val):
+        return self._add_param('signatureDefKey', val)
+
+
+class TFTableModelPredictor(Model, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tensorflow.TFTableModelPredictor'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TFTableModelPredictor, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputSchemaStr(self, val):
+        return self._add_param('outputSchemaStr', val)
+
+    def setGraphDefTag(self, val):
+        return self._add_param('graphDefTag', val)
+
+    def setInputSignatureDefs(self, val):
+        return self._add_param('inputSignatureDefs', val)
+
+    def setOutputSignatureDefs(self, val):
+        return self._add_param('outputSignatureDefs', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setSignatureDefKey(self, val):
+        return self._add_param('signatureDefKey', val)
+
+
+class TFTableModelTrainer(Estimator):
+    CLS_NAME = 'com.alibaba.alink.pipeline.tensorflow.TFTableModelTrainer'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TFTableModelTrainer, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputSchemaStr(self, val):
+        return self._add_param('outputSchemaStr', val)
+
+    def setGraphDefTag(self, val):
+        return self._add_param('graphDefTag', val)
+
+    def setInputSignatureDefs(self, val):
+        return self._add_param('inputSignatureDefs', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setOutputSignatureDefs(self, val):
+        return self._add_param('outputSignatureDefs', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setSignatureDefKey(self, val):
+        return self._add_param('signatureDefKey', val)
+
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
+    def setUserParams(self, val):
+        return self._add_param('userParams', val)
+
+
+class TensorToVector(Transformer, LocalPredictable):
+    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.TensorToVector'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TensorToVector, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setConvertMethod(self, val):
+        return self._add_param('convertMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class TextApproxNearestNeighbor(Estimator):
     CLS_NAME = 'com.alibaba.alink.pipeline.similarity.TextApproxNearestNeighbor'
     OP_TYPE = 'FUNCTION'
@@ -1045,479 +1715,3 @@ class VectorMaxAbsScalerModel(Model, LocalPredictable):
     def setOutputCol(self, val):
         return self._add_param('outputCol', val)
 
-
-class VectorMinMaxScaler(Estimator, HasLazyPrintModelInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMinMaxScaler'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMinMaxScaler, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setMax(self, val):
-        return self._add_param('max', val)
-
-    def setMin(self, val):
-        return self._add_param('min', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorMinMaxScalerModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorMinMaxScalerModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorMinMaxScalerModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorNearestNeighbor(Estimator):
-    CLS_NAME = 'com.alibaba.alink.pipeline.similarity.VectorNearestNeighbor'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNearestNeighbor, self).__init__(*args, **kwargs)
-        pass
-
-    def setIdCol(self, val):
-        return self._add_param('idCol', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setMetric(self, val):
-        return self._add_param('metric', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setRadius(self, val):
-        return self._add_param('radius', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setTopN(self, val):
-        return self._add_param('topN', val)
-
-
-class VectorNearestNeighborModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.similarity.VectorNearestNeighborModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNearestNeighborModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setRadius(self, val):
-        return self._add_param('radius', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setTopN(self, val):
-        return self._add_param('topN', val)
-
-
-class VectorNormalizer(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorNormalizer'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorNormalizer, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setP(self, val):
-        return self._add_param('p', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorPolynomialExpand(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorPolynomialExpand'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorPolynomialExpand, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setDegree(self, val):
-        return self._add_param('degree', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorSizeHint(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorSizeHint'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorSizeHint, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setSize(self, val):
-        return self._add_param('size', val)
-
-    def setHandleInvalidMethod(self, val):
-        return self._add_param('handleInvalidMethod', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorSlicer(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorSlicer'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorSlicer, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setIndices(self, val):
-        return self._add_param('indices', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorStandardScaler(Estimator, HasLazyPrintModelInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorStandardScaler'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorStandardScaler, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setWithMean(self, val):
-        return self._add_param('withMean', val)
-
-    def setWithStd(self, val):
-        return self._add_param('withStd', val)
-
-
-class VectorStandardScalerModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.vector.VectorStandardScalerModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorStandardScalerModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-
-class VectorToColumns(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.VectorToColumns'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToColumns, self).__init__(*args, **kwargs)
-        pass
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToCsv(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.VectorToCsv'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToCsv, self).__init__(*args, **kwargs)
-        pass
-
-    def setCsvCol(self, val):
-        return self._add_param('csvCol', val)
-
-    def setSchemaStr(self, val):
-        return self._add_param('schemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setCsvFieldDelimiter(self, val):
-        return self._add_param('csvFieldDelimiter', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setQuoteChar(self, val):
-        return self._add_param('quoteChar', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToJson(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.VectorToJson'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToJson, self).__init__(*args, **kwargs)
-        pass
-
-    def setJsonCol(self, val):
-        return self._add_param('jsonCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class VectorToKv(Transformer, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.dataproc.format.VectorToKv'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToKv, self).__init__(*args, **kwargs)
-        pass
-
-    def setKvCol(self, val):
-        return self._add_param('kvCol', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setKvColDelimiter(self, val):
-        return self._add_param('kvColDelimiter', val)
-
-    def setKvValDelimiter(self, val):
-        return self._add_param('kvValDelimiter', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class Word2Vec(Estimator, HasLazyPrintTrainInfo):
-    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.Word2Vec'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Word2Vec, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setMinCount(self, val):
-        return self._add_param('minCount', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumIter(self, val):
-        return self._add_param('numIter', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setPredMethod(self, val):
-        return self._add_param('predMethod', val)
-
-    def setRandomWindow(self, val):
-        return self._add_param('randomWindow', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-    def setWindow(self, val):
-        return self._add_param('window', val)
-
-    def setWordDelimiter(self, val):
-        return self._add_param('wordDelimiter', val)
-
-
-class Word2VecModel(Model, LocalPredictable):
-    CLS_NAME = 'com.alibaba.alink.pipeline.nlp.Word2VecModel'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Word2VecModel, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setPredMethod(self, val):
-        return self._add_param('predMethod', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setWordDelimiter(self, val):
-        return self._add_param('wordDelimiter', val)
-
