@@ -89,11 +89,22 @@ class LocalJvmBridge(object):
         # always redirect stdout, and only redirect stderr in debug_mode and not in IPython (will fail)
         redirect_stderr = sys.stderr if debug_mode and not in_ipython() else None
 
+        try:
+            from pyflink.pyflink_gateway_server import construct_log_settings
+            if os.name != 'nt':
+                log_settings = construct_log_settings()
+            else:
+                log_settings = []
+            if 'FLINK_PLUGINS_DIR' in os.environ:
+                os.environ.pop('FLINK_PLUGINS_DIR')
+        except ImportError:
+            log_settings = []
+
         if g_config['gateway_port'] is not None:
             self.port = int(g_config['gateway_port'])
         else:
             self.port = launch_gateway(
-                port=0, javaopts=[], die_on_exit=True, daemonize_redirect=True,
+                port=0, javaopts=[*log_settings], die_on_exit=True, daemonize_redirect=True,
                 redirect_stdout=sys.stdout, redirect_stderr=redirect_stderr,
                 classpath=os.pathsep.join(list_all_jars()))
         print('JVM listening on 127.0.0.1:{}'.format(self.port))
