@@ -301,6 +301,47 @@ class AlsUsersPerItemRecommStreamOp(BaseModelStreamOp):
         return self._add_param('reservedCols', val)
 
 
+class ArimaStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.ArimaStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ArimaStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOrder(self, val):
+        return self._add_param('order', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setEstMethod(self, val):
+        return self._add_param('estMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeasonalOrder(self, val):
+        return self._add_param('seasonalOrder', val)
+
+    def setSeasonalPeriod(self, val):
+        return self._add_param('seasonalPeriod', val)
+
+
 class AsStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.sql.AsStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -315,6 +356,218 @@ class AsStreamOp(StreamOperator):
         return self._add_param('clause', val)
 
 
+class AutoArimaStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.AutoArimaStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AutoArimaStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setD(self, val):
+        return self._add_param('d', val)
+
+    def setEstMethod(self, val):
+        return self._add_param('estMethod', val)
+
+    def setIcType(self, val):
+        return self._add_param('icType', val)
+
+    def setMaxOrder(self, val):
+        return self._add_param('maxOrder', val)
+
+    def setMaxSeasonalOrder(self, val):
+        return self._add_param('maxSeasonalOrder', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setSeasonalPeriod(self, val):
+        return self._add_param('seasonalPeriod', val)
+
+
+class AutoGarchStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.AutoGarchStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(AutoGarchStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setIcType(self, val):
+        return self._add_param('icType', val)
+
+    def setIfGARCH11(self, val):
+        return self._add_param('ifGARCH11', val)
+
+    def setMaxOrder(self, val):
+        return self._add_param('maxOrder', val)
+
+    def setMinusMean(self, val):
+        return self._add_param('minusMean', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextClassifierPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.BertTextClassifierPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextClassifierPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextEmbeddingStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.BertTextEmbeddingStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextEmbeddingStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setModelPath(self, val):
+        return self._add_param('modelPath', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setBertModelName(self, val):
+        return self._add_param('bertModelName', val)
+
+    def setDoLowerCase(self, val):
+        return self._add_param('doLowerCase', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setLayer(self, val):
+        return self._add_param('layer', val)
+
+    def setMaxSeqLength(self, val):
+        return self._add_param('maxSeqLength', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextPairClassifierPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.BertTextPairClassifierPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextPairClassifierPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextPairRegressorPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.BertTextPairRegressorPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextPairRegressorPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class BertTextRegressorPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.BertTextRegressorPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(BertTextRegressorPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setInferBatchSize(self, val):
+        return self._add_param('inferBatchSize', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class BinarizerStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.feature.BinarizerStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -959,6 +1212,44 @@ class DCTStreamOp(StreamOperator):
         return self._add_param('reservedCols', val)
 
 
+class DLLauncherStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.common.dl.DLLauncherStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DLLauncherStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setEntryFunc(self, val):
+        return self._add_param('entryFunc', val)
+
+    def setOutputSchemaStr(self, val):
+        return self._add_param('outputSchemaStr', val)
+
+    def setScript(self, val):
+        return self._add_param('script', val)
+
+    def setIntraOpParallelism(self, val):
+        return self._add_param('intraOpParallelism', val)
+
+    def setNumPSs(self, val):
+        return self._add_param('numPSs', val)
+
+    def setNumWorkers(self, val):
+        return self._add_param('numWorkers', val)
+
+    def setPythonEnv(self, val):
+        return self._add_param('pythonEnv', val)
+
+    def setUserDefinedParams(self, val):
+        return self._add_param('userDefinedParams', val)
+
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
+
 class DecisionTreePredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.classification.DecisionTreePredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -1020,6 +1311,35 @@ class DecisionTreeRegPredictStreamOp(BaseModelStreamOp):
         return self._add_param('reservedCols', val)
 
 
+class DeepARPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.timeseries.DeepARPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(DeepARPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setValueCol(self, val):
+        return self._add_param('valueCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictNum(self, val):
+        return self._add_param('predictNum', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class DocCountVectorizerPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.DocCountVectorizerPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -1184,323 +1504,3 @@ class EvalMultiClassStreamOp(StreamOperator):
     def setTimeInterval(self, val):
         return self._add_param('timeInterval', val)
 
-
-class FeatureHasherStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.feature.FeatureHasherStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FeatureHasherStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setSelectedCols(self, val):
-        return self._add_param('selectedCols', val)
-
-    def setCategoricalCols(self, val):
-        return self._add_param('categoricalCols', val)
-
-    def setNumFeatures(self, val):
-        return self._add_param('numFeatures', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class FilterStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.FilterStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FilterStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setClause(self, val):
-        return self._add_param('clause', val)
-
-
-class FlattenKObjectStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.recommendation.FlattenKObjectStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FlattenKObjectStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setOutputCols(self, val):
-        return self._add_param('outputCols', val)
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setOutputColTypes(self, val):
-        return self._add_param('outputColTypes', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class FmClassifierPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.FmClassifierPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FmClassifierPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class FmItemsPerUserRecommStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.recommendation.FmItemsPerUserRecommStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FmItemsPerUserRecommStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setRecommCol(self, val):
-        return self._add_param('recommCol', val)
-
-    def setUserCol(self, val):
-        return self._add_param('userCol', val)
-
-    def setExcludeKnown(self, val):
-        return self._add_param('excludeKnown', val)
-
-    def setInitRecommCol(self, val):
-        return self._add_param('initRecommCol', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class FmRegressorPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.regression.FmRegressorPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FmRegressorPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class FmUsersPerItemRecommStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.recommendation.FmUsersPerItemRecommStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FmUsersPerItemRecommStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setItemCol(self, val):
-        return self._add_param('itemCol', val)
-
-    def setRecommCol(self, val):
-        return self._add_param('recommCol', val)
-
-    def setExcludeKnown(self, val):
-        return self._add_param('excludeKnown', val)
-
-    def setInitRecommCol(self, val):
-        return self._add_param('initRecommCol', val)
-
-    def setK(self, val):
-        return self._add_param('k', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class FtrlModelFilterStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.onlinelearning.FtrlModelFilterStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FtrlModelFilterStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setAccuracyThreshold(self, val):
-        return self._add_param('accuracyThreshold', val)
-
-    def setAucThreshold(self, val):
-        return self._add_param('aucThreshold', val)
-
-    def setPositiveLabelValueString(self, val):
-        return self._add_param('positiveLabelValueString', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class FtrlPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.onlinelearning.FtrlPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FtrlPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setPredictionCol(self, val):
-        return self._add_param('predictionCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setPredictionDetailCol(self, val):
-        return self._add_param('predictionDetailCol', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-
-class FtrlTrainStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.onlinelearning.FtrlTrainStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(FtrlTrainStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setLabelCol(self, val):
-        return self._add_param('labelCol', val)
-
-    def setVectorSize(self, val):
-        return self._add_param('vectorSize', val)
-
-    def setAlpha(self, val):
-        return self._add_param('alpha', val)
-
-    def setBeta(self, val):
-        return self._add_param('beta', val)
-
-    def setFeatureCols(self, val):
-        return self._add_param('featureCols', val)
-
-    def setL1(self, val):
-        return self._add_param('l1', val)
-
-    def setL2(self, val):
-        return self._add_param('l2', val)
-
-    def setTimeInterval(self, val):
-        return self._add_param('timeInterval', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setWithIntercept(self, val):
-        return self._add_param('withIntercept', val)
-
